pub struct SandboxedFileProvider { /* private fields */ }Expand description
Sandboxed file provider that restricts access to the pack directory
This is the default provider used during template rendering. It ensures that templates cannot access files outside the pack root.
Implementations